@@ -12,12 +12,13 @@ import logging
 import subprocess
 from time import sleep
 from random import randint
+from general_conf import path_config
 logger = logging.getLogger(__name__)
 
 
 class RunnerTestMode(GeneralClass):
 
-    def __init__(self, config='/etc/bck.conf'):
+    def __init__(self, config=path_config.config_path_file):
         self.conf = config
         super().__init__(config=self.conf)
 
@@ -336,7 +337,7 @@ class RunnerTestMode(GeneralClass):
         :param mysql_slave_client_cmd: Slave client string
         :param mysql_master_client_cmd: Master client string
         :param is_slave: flag for passing if set global gtid_purged grabbed from slave or not
-        :return: True if succes or raise RuntimeError exception fom run_sql_command()
+        :return: True if success or raise RuntimeError exception fom run_sql_command()
         """
 
         logger.debug("Started to make this new server as slave...")
@@ -401,7 +402,7 @@ class RunnerTestMode(GeneralClass):
 
         return True
 
-    def wipe_backup_prepare_copyback(self, basedir):
+    def wipe_backup_prepare_copyback(self, basedir, keyring_vault=0):
         """
         Method Backup + Prepare and Copy-back actions.
         It is also going to create slave server from backup of master and start.
@@ -412,8 +413,14 @@ class RunnerTestMode(GeneralClass):
         for options in ConfigGenerator(config=self.conf).options_combination_generator(self.mysql_options):
             c_count = c_count + 1
             options = " ".join(options)
-            if '5.7' in basedir:
-                options = options + " " + self.df_mysql_options.format(basedir, c_count)
+            if '5.7' in basedir or '8.0' in basedir:
+                if keyring_vault == 0:
+                    options = options + " " + self.df_mysql_options.format(basedir, c_count)
+                elif keyring_vault == 1:
+                    # The keyring_vault options must be provided manually with full path in config.
+                    # Such as: --early-plugin-load=keyring_vault=keyring_vault.so,--loose-keyring_vault_config=/sda/vault_server/keyring_vault.cnf
+                    # It indicates that there is no need to pass basedir that's why only passing the [--server-id=c_count]
+                    options = options + " " + self.df_mysql_options.format(c_count)
             else:
                 options = options + " " + self.df_mysql_options.format(c_count)
             logger.debug("*********************************")
@@ -491,15 +498,17 @@ class RunnerTestMode(GeneralClass):
                             cnf_obj = ConfigGenerator(config=self.conf)
                             slave_conf_path = self.backupdir + "/cycle{}".format(c_count)
                             if ('5.7' in basedir) and ('2_4_ps_5_7' in self.conf):
-                                slave_conf_file = 'xb_2_4_ps_5_7_slave.conf'
+                                slave_conf_file = 'xb_2_4_ps_5_7_slave.cnf'
+                            elif ('8.0' in basedir) and ('8_0_ps_8_0' in self.conf):
+                                slave_conf_file = 'xb_8_0_ps_8_0_slave.cnf'
                             elif ('5.6' in basedir) and ('2_4_ps_5_6' in self.conf):
-                                slave_conf_file = 'xb_2_4_ps_5_6_slave.conf'
+                                slave_conf_file = 'xb_2_4_ps_5_6_slave.cnf'
                             elif ('5.6' in basedir) and ('2_3_ps_5_6' in self.conf):
-                                slave_conf_file = 'xb_2_3_ps_5_6_slave.conf'
+                                slave_conf_file = 'xb_2_3_ps_5_6_slave.cnf'
                             elif ('5.5' in basedir) and ('2_3_ps_5_5' in self.conf):
-                                slave_conf_file = 'xb_2_3_ps_5_5_slave.conf'
+                                slave_conf_file = 'xb_2_3_ps_5_5_slave.cnf'
                             elif ('5.5' in basedir) and ('2_4_ps_5_5' in self.conf):
-                                slave_conf_file = 'xb_2_4_ps_5_5_slave.conf'
+                                slave_conf_file = 'xb_2_4_ps_5_5_slave.cnf'
 
                             cnf_obj.generate_config_files(test_path=self.testpath,
                                                           conf_file=slave_conf_file,
